# Supported Models

Currently, docugenius supports the following models:

- `openai:gpt-4o`
- `openai:gpt-4-mini`

The library is designed to be easily extensible, so you can add support for other models by subclassing the `Genius` class and implementing the necessary methods.

For more information on how to add support for other models, see the [Extending Docugenius](extending-docugenius.md) section.
